@@ -4,7 +4,7 @@ import (
 	"context"
 	"strings"
 
-	"github.com/urfave/cli"
+	"github.com/urfave/cli/v2"
 )
 
 func Modify(c *cli.Context) error {
